@@ -894,10 +894,7 @@ sub _get_file_list {
 sub _get_file_obj {
     my $self = shift;
     my $file = shift;
-    if (ref($file) eq 'ARRAY') {
-        return map { $self->_generate_file( $_ ) } @$file;
-    }
-    return $self->_generate_file( $file );
+    return $self->_generate_file( ref($file) eq 'ARRAY' ? @$file : $file );
 }
 
 sub _generate_file {
